<?php
/**
 * Plugin Name: BOGO (Buy One, Get One) for WooCommerce
 * Plugin URI: https://www.dorzki.io/add-bogo-to-woocommerce/?utm_source=wordpress-plugin&utm_medium=plugin-uri&utm_campaign=tutorial-code
 * Description: BOGO (Buy One, Get One) Plugin for WooCommerce.
 * Version: 1.0.0
 * Requires at least: 5.0
 * Requires PHP: 7.4
 * Author: dorzki
 * Author URI: https://www.dorzki.io/?utm_source=wordpress-plugin&utm_medium=author-uri&utm_campaign=tutorial-code
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: dorzki-woocommerce-bogo
 *
 * @package    WordPress
 * @subpackage Plugins
 * @author     Dor Zuberi <admin@dorzki.io>
 * @link       https://www.dorzki.io
 * @version    1.0.0
 */

// Block if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Plugin Constants
if ( ! defined( 'DRZK_WC_BOGO_PATH' ) ) {
	define( 'DRZK_WC_BOGO_PATH', __DIR__ );
}


/**
 * Checks if WooCommerce is installed and activated.
 */
function dorzki_wc_bogo_check_required_plugins() {
	if ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) {
		add_action( 'admin_notices', 'dorzki_wc_bogo_display_woocommerce_notice' );

		return;
	}

	include_once DRZK_WC_BOGO_PATH . '/class-plugin.php';
}

add_action( 'plugins_loaded', 'dorzki_wc_bogo_check_required_plugins' );


/**
 * Displays an admin notice for WooCommerce.
 */
function dorzki_wc_bogo_display_woocommerce_notice() {
	$notice = sprintf(
	/* translators: 1: WooCommerce 2: Plugin Name */
		esc_html__( '"%1$s" is required to be installed and activated in order to use "%2$s".', 'dorzki-woocommerce-bogo' ),
		'<strong>' . esc_html__( 'WooCommerce', 'dorzki-woocommerce-bogo' ) . '</strong>',
		'<strong>' . esc_html__( 'BOGO (Buy One, Get One) for WooCommerce', 'dorzki-woocommerce-bogo' ) . '</strong>'
	);

	echo "<div class='notice notice-error'><p>{$notice}</p></div>";
}
